@@ -1,6 +1,6 @@
 package Net::Riak;
 BEGIN {
-  $Net::Riak::VERSION = '0.10';
+  $Net::Riak::VERSION = '0.11';
 }
 
 # ABSTRACT: Interface to Riak
@@ -44,7 +44,7 @@ Net::Riak - Interface to Riak
 
 =head1 VERSION
 
-version 0.10
+version 0.11
 
 =head1 SYNOPSIS
 
@@ -53,7 +53,9 @@ version 0.10
     my $obj    = $bucket->new_object('new_post', {title => 'foo', content => 'bar'});
     $obj->store;
 
-    my $obj = $bucket->get('new_post');
+    $obj = $bucket->get('new_post');
+    say "title for ".$obj->key." is ".$obj->data->{title};
+
     my $req = $client->http_request; # last request
     $client->http_response # last response
 
